summaryrefslogtreecommitdiffstats
path: root/content/port
diff options
context:
space:
mode:
authoraurimas@chromium.org <aurimas@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-06-18 11:26:47 +0000
committeraurimas@chromium.org <aurimas@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-06-18 11:26:47 +0000
commitcb9e2632d08ca94423a5d0ba6d02590baedc3917 (patch)
treecd234f6dfb703c55c05d3ff98b00441f0087d0ef /content/port
parent804751413d2b0b64084dade35e5d45c0ad67ce16 (diff)
downloadchromium_src-cb9e2632d08ca94423a5d0ba6d02590baedc3917.zip
chromium_src-cb9e2632d08ca94423a5d0ba6d02590baedc3917.tar.gz
chromium_src-cb9e2632d08ca94423a5d0ba6d02590baedc3917.tar.bz2
Split TextInputStateChanged IPC into two IPCs
As part of Android's IME rewrite we will try to limit the number of updates sent from render -> browser. This CL splits the IPC that sends these updates into two. Only text type and can_compose inline are used by desktop OSes. Android uses the rest of the content of that IPC. This CL will enable the tweaking of when UpdateTextInputState is called without affecting other platforms. BUG=246862 Review URL: https://chromiumcodereview.appspot.com/16379006 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@206935 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/port')
-rw-r--r--content/port/browser/render_widget_host_view_port.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/content/port/browser/render_widget_host_view_port.h b/content/port/browser/render_widget_host_view_port.h
index 9b14762..ddfaffb 100644
--- a/content/port/browser/render_widget_host_view_port.h
+++ b/content/port/browser/render_widget_host_view_port.h
@@ -98,9 +98,9 @@ class CONTENT_EXPORT RenderWidgetHostViewPort : public RenderWidgetHostView,
// Indicates whether the page has finished loading.
virtual void SetIsLoading(bool is_loading) = 0;
- // Updates the state of the input method attached to the view.
- virtual void TextInputStateChanged(
- const ViewHostMsg_TextInputState_Params& params) = 0;
+ // Updates the type of the input method attached to the view.
+ virtual void TextInputTypeChanged(ui::TextInputType type,
+ bool can_compose_inline) = 0;
// Cancel the ongoing composition of the input method attached to the view.
virtual void ImeCancelComposition() = 0;